pub struct HeaderProfile {
pub user_agent: String,
pub headers: Vec<(String, String)>,
}Expand description
A browser user agent and its ordered companion HTTP headers.
Fields
user_agent: StringBrowser user-agent value.
headers: Vec<(String, String)>Ordered header name and value pairs associated with the user agent.